@@ -33,11 +33,11 @@ public slots:
 signals:
 	void connectToHost(QString url, int quality, int listen_port);
 private slots:
-	void indexChanged(int index);
 	void hostnameUpdated(QString newtext);
 private:
 	QHBoxLayout layout;
 	QStringList hostnames_sorted;
+	QPushButton *done;
 	QComboBox hosts;
 	QMaemo5ListPickSelector *quality_selector;
 };
