@@ -21,6 +21,7 @@
 #include "keymenu.h"
 #include "mainwindow.h"
 #include "preferences.h"
+#include "scrollarea.h"
 #include "vncview.h"
 
 #ifdef Q_WS_MAEMO_5
@@ -58,20 +59,13 @@ MainWindow::MainWindow(QString url, int quality):
 	toolbar->addAction(QIcon("/usr/share/icons/hicolor/48x48/hildon/control_keyboard.png"), "", this, SLOT(showInputPanel()));
 #endif
 
-	/*
-	//move remaining buttons to the right
-	QWidget *spacer = new QWidget();
-	spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-	toolbar->addWidget(spacer);
-	*/
-
 	QSettings settings;
 	zoom_slider = new QSlider(Qt::Horizontal, 0);
 	zoom_slider->setRange(0, 100);
 	connect(zoom_slider, SIGNAL(valueChanged(int)),
 		this, SLOT(setZoomLevel(int)));
 	connect(zoom_slider, SIGNAL(sliderReleased()),
-		this, SLOT(forceRepaint()));
+		this, SLOT(zoomSliderReleased()));
 	zoom_slider->setValue(settings.value("zoomlevel", 95).toInt());
 	toolbar->addWidget(zoom_slider);
 
@@ -125,7 +119,10 @@ MainWindow::MainWindow(QString url, int quality):
 		this, SLOT(updateScreenSpaceDelayed()));
 
 	setCentralWidget(scroll_area);
-	new FullScreenExitButton(this);
+
+	FullScreenExitButton* fullscreen_exit_button = new FullScreenExitButton(this);
+	connect(fullscreen_exit_button, SIGNAL(clicked()),
+		this, SLOT(toggleFullscreen()));
 
 	grabZoomKeys(true);
 	reloadSettings();
@@ -171,7 +168,7 @@ void MainWindow::closeEvent(QCloseEvent*) {
 
 void MainWindow::about() {
 	QMessageBox::about(this, tr("About Presence VNC"),
-		tr("<center><h1>Presence VNC 0.6</h1>\
+		tr("<center><h1>Presence VNC 0.7</h1>\
 <p>A touchscreen friendly VNC client</p>\
 <p><a href=\"https://garage.maemo.org/projects/presencevnc/\">https://garage.maemo.org/projects/presencevnc</a></p></center>\
 <small><p>&copy;2010 Christian Pulvermacher &lt;pulvermacher@gmx.de&gt;<br />\
@@ -236,25 +233,25 @@ void MainWindow::statusChanged(RemoteView::RemoteStatus status)
 		toolbar->setEnabled(true);
 
 		vnc_view->setZoomLevel(zoom_slider->value());
-		vnc_view->forceFullRepaint();
+		vnc_view->useFastTransformations(false);
+		vnc_view->repaint();
 		break;
 	case RemoteView::Disconnecting:
-		if(old_status != RemoteView::Disconnected) { //Disconnecting also occurs while connecting, so check last state
-#ifdef Q_WS_MAEMO_5
-			if(disconnect_action->isEnabled()) //don't show when manually disconnecting
-				QMaemo5InformationBox::information(this, tr("Connection lost"));
-#endif
-			
-			//clean up
-			scroll_area->setWidget(0);
-			vnc_view = 0;
-			disconnect_action->setEnabled(false);
-			toolbar->setEnabled(false);
+		if(old_status == RemoteView::Disconnected) //Disconnecting also occurs while connecting, so check last state
+			break;
 
-			//exit fullscreen mode
-			if(windowState() & Qt::WindowFullScreen)
-				setWindowState(windowState() ^ Qt::WindowFullScreen);
-		}
+		if(disconnect_action->isEnabled()) //don't show when manually disconnecting
+			scroll_area->showMessage(tr("Connection lost"));
+		
+		//clean up
+		scroll_area->setWidget(0);
+		vnc_view = 0;
+		disconnect_action->setEnabled(false);
+		toolbar->setEnabled(false);
+
+		//exit fullscreen mode
+		if(windowState() & Qt::WindowFullScreen)
+			setWindowState(windowState() ^ Qt::WindowFullScreen);
 		break;
 	case RemoteView::Disconnected:
 #ifdef Q_WS_MAEMO_5
@@ -271,12 +268,6 @@ void MainWindow::statusChanged(RemoteView::RemoteStatus status)
 	old_status = status;
 }
 
-void MainWindow::forceRepaint()
-{
-	if(vnc_view)
-		vnc_view->forceFullRepaint();
-}
-
 //updates available screen space for current zoom level
 //necessary when rotating, showing fullscreen, etc.
 void MainWindow::updateScreenSpace()
@@ -324,8 +315,10 @@ void MainWindow::showPreferences()
 
 void MainWindow::reloadSettings()
 {
-#ifdef Q_WS_MAEMO_5
 	QSettings settings;
+	zoom_to_cursor = settings.value("zoom_to_cursor", true).toBool();
+	
+#ifdef Q_WS_MAEMO_5
 	int rotation = settings.value("screen_rotation", 0).toInt();
 	setAttribute(Qt::WA_Maemo5AutoOrientation, rotation == 0);
 	setAttribute(Qt::WA_Maemo5LandscapeOrientation, rotation == 1);
@@ -367,19 +360,39 @@ void MainWindow::setZoomLevel(int level)
 	if(!vnc_view)
 		return;
 	
-	int old_width = vnc_view->width();
+	const qreal old_factor = vnc_view->zoomFactor();
 	QPoint center = vnc_view->visibleRegion().boundingRect().center();
 
 	vnc_view->setZoomLevel(level);
 
-	int new_width = vnc_view->width();
+	const qreal new_factor = vnc_view->zoomFactor();
 
 	//scroll to center, if zoom level actually changed
-	if(new_width != old_width) {
-		center = center * (double(new_width)/old_width);
+	if(old_factor != new_factor) {
+		if(zoom_to_cursor)
+			center = new_factor * vnc_view->cursorPosition();
+		else //zoom to center of visible region
+			center = center * (double(new_factor)/old_factor);
+
 		scroll_area->ensureVisible(center.x(), center.y(),
 			vnc_view->visibleRegion().boundingRect().width()/2,
 			vnc_view->visibleRegion().boundingRect().height()/2);
+
+		vnc_view->useFastTransformations(zoom_slider->isSliderDown());
 		vnc_view->update();
+
+		scroll_area->showMessage(tr("Zoom: %1\%").arg(qRound(100*new_factor)));
 	}
 }
+
+void MainWindow::zoomSliderReleased()
+{
+	static QTime time;
+	if(!time.isNull() and time.elapsed() < 500) //double clicked
+		zoom_slider->setValue(95); //100%
+	
+	time.restart();
+
+	//stopped zooming, reenable high quality
+	vnc_view->useFastTransformations(false);
+}
