@@ -25,20 +25,7 @@
 #include <QtGui>
 
 class KeyMenu;
-
-//fix tearing during scrolling
-class ScrollArea : public QScrollArea {
-public:
-	ScrollArea(QWidget *parent) : QScrollArea(parent) { }
-protected:
-	virtual void scrollContentsBy(int dx, int dy)
-	{
-		QScrollArea::scrollContentsBy(dx, dy);
-		if(widget())
-			widget()->update(); //update whole widget
-	}
-};
-
+class ScrollArea;
 
 class MainWindow : public QMainWindow {
 	Q_OBJECT
@@ -49,7 +36,6 @@ public slots:
 	void showConnectDialog();
 	void connectToHost(QString url, int quality, int listen_port);
 	void disconnectFromHost();
-	void forceRepaint();
 	void updateScreenSpace();
 	void updateScreenSpaceDelayed();
 	void sendTab() { vnc_view->sendKey(Qt::Key_Tab); }
@@ -57,23 +43,26 @@ public slots:
 	void sendPgUp() { vnc_view->sendKey(Qt::Key_PageUp); }
 	void sendPgDn() { vnc_view->sendKey(Qt::Key_PageDown); }
 	void sendReturn() { vnc_view->sendKey(Qt::Key_Return); }
-    void setZoomLevel(int level);
+	void setZoomLevel(int level);
 	void showInputPanel();
 	void showKeyMenu();
 	void showPreferences();
 	void statusChanged(RemoteView::RemoteStatus status);
 	void toggleFullscreen();
+	void zoomSliderReleased();
 protected:
 	void closeEvent(QCloseEvent*);
 	void resizeEvent(QResizeEvent *event);
 private:
 	void grabZoomKeys(bool grab);
 	void reloadSettings();
+
 	VncView *vnc_view;
 	ScrollArea *scroll_area;
 	QToolBar *toolbar;
 	QSlider *zoom_slider;
 	QAction *scaling, *show_toolbar, *disconnect_action;
 	KeyMenu *key_menu;
+	bool zoom_to_cursor;
 };
 #endif
