@@ -244,25 +244,8 @@ void RemoteView::saveWalletPassword(const QString &password, bool fromUserNameOn
 
 QCursor RemoteView::localDotCursor() const
 {
-#ifdef QTONLY
-const uchar bits[] =
-{ 0xffffffff, 0xffffffff, 0xffffffff,
-  0xffffffff, 0xff000000, 0xffffffff,
-  0xffffffff, 0xffffffff, 0xffffffff };
-
-    QBitmap cursorBitmap = QBitmap::fromData(QSize(3,3), bits , QImage::Format_RGB32);
-    QBitmap cursorMask(QSize(3,3));
-    cursorMask.clear();
-
-    return QCursor(cursorBitmap, cursorMask);
-    //return QCursor(); //TODO
-#else
-    QBitmap cursorBitmap(KGlobal::dirs()->findResource("appdata",
-                                                       "pics/pointcursor.png"));
-    QBitmap cursorMask(KGlobal::dirs()->findResource("appdata",
-                                                     "pics/pointcursormask.png"));
-    return QCursor(cursorBitmap, cursorMask);
-#endif
+	//we take care of this in paintEvent()
+	return QCursor(Qt::BlankCursor);
 }
 
 void RemoteView::focusInEvent(QFocusEvent *event)
