@@ -65,16 +65,15 @@ VncView::VncView(QWidget *parent, const KUrl &url, RemoteView::Quality quality,
         m_buttonMask(0),
 	cursor_x(0),
 	cursor_y(0),
-        m_repaint(false),
         m_quitFlag(false),
         m_firstPasswordTry(true),
         m_dontSendClipboard(false),
         m_horizontalFactor(1.0),
         m_verticalFactor(1.0),
         m_forceLocalCursor(false),
-	force_full_repaint(false),
 	quality(quality),
-	listen_port(listen_port)
+	listen_port(listen_port),
+	transformation_mode(Qt::FastTransformation)
 {
     m_url = url;
     m_host = url.host();
@@ -106,12 +105,6 @@ VncView::~VncView()
     startQuitting();
 }
 
-void VncView::forceFullRepaint()
-{
-	force_full_repaint = true;
-	repaint();
-}
-
 bool VncView::eventFilter(QObject *obj, QEvent *event)
 {
     if (m_viewOnly) {
@@ -304,7 +297,7 @@ void VncView::updateImage(int x, int y, int w, int h)
 
     m_frame = vncThread.image();
 
-    if (!m_initDone) {
+    if (!m_initDone) { //TODO this seems an odd place for initialization
         setAttribute(Qt::WA_StaticContents);
         setAttribute(Qt::WA_OpaquePaintEvent);
         installEventFilter(this);
@@ -314,7 +307,6 @@ void VncView::updateImage(int x, int y, int w, int h)
         setMouseTracking(true); // get mouse events even when there is no mousebutton pressed
         setFocusPolicy(Qt::WheelFocus);
         setStatus(Connected);
-//         emit framebufferSizeChanged(m_frame.width(), m_frame.height());
         emit connected();
         
 		resize(width(), height());
@@ -328,12 +320,12 @@ void VncView::updateImage(int x, int y, int w, int h)
 	    old_frame_size = m_frame.size();
         kDebug(5011) << "Updating framebuffer size";
 		setZoomLevel();
+		useFastTransformations(false);
+
         emit framebufferSizeChanged(m_frame.width(), m_frame.height());
     }
 
-    m_repaint = true;
     repaint(qRound(m_x * m_horizontalFactor), qRound(m_y * m_verticalFactor), qRound(m_w * m_horizontalFactor), qRound(m_h * m_verticalFactor));
-    m_repaint = false;
 }
 
 void VncView::setViewOnly(bool viewOnly)
@@ -397,47 +389,31 @@ void VncView::setCut(const QString &text)
 
 void VncView::paintEvent(QPaintEvent *event)
 {
-     //kDebug(5011) << "paint event: x: " << m_x << ", y: " << m_y << ", w: " << m_w << ", h: " << m_h;
     if (m_frame.isNull() || m_frame.format() == QImage::Format_Invalid) {
-        kDebug(5011) << "no valid image to paint";
+        //no valid image to paint
         RemoteView::paintEvent(event);
         return;
     }
 
     event->accept();
 
+	const QRect update_rect = event->rect();
     QPainter painter(this);
+	if (update_rect != rect()) {
+		// kDebug(5011) << "Partial repaint";
+		const int sx = qRound(update_rect.x()/m_horizontalFactor);
+		const int sy = qRound(update_rect.y()/m_verticalFactor);
+		const int sw = qRound(update_rect.width()/m_horizontalFactor);
+		const int sh = qRound(update_rect.height()/m_verticalFactor);
 
-	Qt::TransformationMode transformation_mode = Qt::SmoothTransformation;
-	if( m_horizontalFactor >= 1.0 )
-		transformation_mode = Qt::FastTransformation;
+		painter.drawImage(update_rect, 
+			  m_frame.copy(sx, sy, sw, sh)
+			  .scaled(update_rect.size(), Qt::IgnoreAspectRatio, transformation_mode));
+	} else {
+		//kDebug(5011) << "Full repaint" << width() << height() << m_frame.width() << m_frame.height();
 
-    if (m_repaint and !force_full_repaint) {
-//         kDebug(5011) << "normal repaint";
-        painter.drawImage(QRect(qRound(m_x*m_horizontalFactor), qRound(m_y*m_verticalFactor),
-                                qRound(m_w*m_horizontalFactor), qRound(m_h*m_verticalFactor)), 
-                          m_frame.copy(m_x, m_y, m_w, m_h).scaled(qRound(m_w*m_horizontalFactor), 
-                                                                  qRound(m_h*m_verticalFactor),
-                                                                  Qt::IgnoreAspectRatio, transformation_mode));
-    } else {
-         //kDebug(5011) << "resize repaint";
-        QRect rect = event->rect();
-        if (!force_full_repaint and (rect.width() != width() || rect.height() != height())) {
-          //   kDebug(5011) << "Partial repaint";
-            const int sx = rect.x()/m_horizontalFactor;
-            const int sy = rect.y()/m_verticalFactor;
-            const int sw = rect.width()/m_horizontalFactor;
-            const int sh = rect.height()/m_verticalFactor;
-            painter.drawImage(rect, 
-                              m_frame.copy(sx, sy, sw, sh).scaled(rect.width(), rect.height(),
-                                                                  Qt::IgnoreAspectRatio, transformation_mode));
-        } else {
-             kDebug(5011) << "Full repaint" << width() << height() << m_frame.width() << m_frame.height();
-            painter.drawImage(QRect(0, 0, width(), height()), 
-                              m_frame.scaled(m_frame.width() * m_horizontalFactor, m_frame.height() * m_verticalFactor,
-                                             Qt::IgnoreAspectRatio, transformation_mode));
-			force_full_repaint = false;
-        }
+		painter.drawImage(rect(),
+			m_frame.scaled(size(), Qt::IgnoreAspectRatio, transformation_mode));
     }
 
 	//draw local cursor ourselves, normal mouse pointer doesn't deal with scrolling
@@ -883,5 +859,14 @@ void VncView::inputMethodEvent(QInputMethodEvent *event)
 	}
 }
 
+void VncView::useFastTransformations(bool enabled)
+{
+	if(enabled or zoomFactor() >= 1.0) {
+		transformation_mode = Qt::FastTransformation;
+	} else {
+		transformation_mode = Qt::SmoothTransformation;
+		update();
+	}
+}
 
 #include "moc_vncview.cpp"
