@@ -48,6 +48,7 @@ public:
     QSize sizeHint() const;
     QSize minimumSizeHint() const;
     bool isQuitting();
+    qreal zoomFactor() { return m_horizontalFactor;} //assumes fixed aspect ratio
     void reloadSettings();
     bool start();
     bool supportsScaling() const;
@@ -56,13 +57,14 @@ public:
     void setQuality(int q);
     void setViewOnly(bool viewOnly);
     void showDotCursor(DotCursorState state);
+    void useFastTransformations(bool enabled);
+    QPoint cursorPosition() { return QPoint(cursor_x, cursor_y); }
     
 public slots:
     void setZoomLevel(int level = -1); //'level' doesn't correspond to actual magnification, though mapping is done here
     void sendKey(Qt::Key key);
     void sendKeySequence(QKeySequence keys);
     void startQuitting();
-    void forceFullRepaint();
 
 protected:
     void paintEvent(QPaintEvent *event);
@@ -79,7 +81,6 @@ private:
     QMap<unsigned int, bool> m_mods;
     int m_x, m_y, m_w, m_h;
     int cursor_x, cursor_y;
-    bool m_repaint;
     bool m_quitFlag;
     bool m_firstPasswordTry;
     bool m_dontSendClipboard;
@@ -87,11 +88,11 @@ private:
     qreal m_verticalFactor;
     QImage m_frame;
     bool m_forceLocalCursor;
-    bool force_full_repaint;
     int left_zoom, right_zoom;
     bool disable_tapping;
     RemoteView::Quality quality;
 	int listen_port;
+	Qt::TransformationMode transformation_mode;
 
     void keyEventHandler(QKeyEvent *e);
     void unpressModifiers();
